# 🎴 Character Card Standards

This page explains the standard format and rules used for character cards.

---

## 📐 Card Dimensions

- **Canvas Size:** `800x1120px`
- **Print Equivalent:** 2.5 x 3.5 inches (at 300dpi, classic card format)

---

## 🧩 Layout Regions

Each card is composed of the following sections:

- **Top Name Bar** – Displays character name
- **Series Text** – Indicates the collection or set the card belongs to
- **Main Art Zone** – Character illustration
- **Stats Row** – Shows 3 core stats:
  - **Power**
  - **Charm**
  - **Wit**
- **Flavor Text Box** – Optional quote or description
- **Rarity Marker** – Icon, stars, or color code
- **Artist name** - The creator of the Character illustration
- **Kemoverse ID** - Unique SHA-256 code generated for the card, based on the information of the card (Ommiting art)


---

## 🌟 Rarity Tiers

Each card belongs to a **rarity tier** which affects both appearance and stat limits.

| Rarity       | Total Stats Cap | Visual Features Recommended                     |
|--------------|------------------|-------------------------------------|
| **Common**       | 100              | Plain template, minimal shine       |
| **Uncommon**     | 140              | Slightly enhanced frame             |
| **Rare**         | 180              | Decorative borders, mild shine      |
| **Super Rare**   | 220              | Unique frame, vibrant shine         |
| **Legendary**    | 250              | Custom art frames, animated effects |

---

## 🎲 Rarity Distribution Guidelines

The following table shows an **example** of how many cards you might include *in a 20-card pack*, but the actual number of cards per rarity is flexible.

What **matters most** is that rarities follow the **percentage limits** defined below.  
These limits ensure balance across the entire card pool — regardless of total size.

| Rarity       | Max % Allowed | Example (20 cards) | Weight  | Notes                                 |
|--------------|----------------|--------------------|---------|----------------------------------------|
| **Common**       | No upper limit | 10 cards (50%)       | 0.7     | Can exceed 50% of total if needed      |
| **Uncommon**     | 20%             | 4 cards              | 0.2     | Should not exceed 20% of total         |
| **Rare**         | 15%             | 3 cards              | 0.08    | Should not exceed 15% of total         |
| **Super Rare**   | 10%             | 2 cards              | 0.015   | Should not exceed 10% of total         |
| **Legendary**    | 5%              | 1 card               | 0.005   | Should not exceed 5% of total          |

> ✅ You can include more cards overall (e.g. 40, 100, etc.),  
> 🔒 But rarities from **Uncommon to Legendary** must **not exceed their percentage caps**.  
> 🪶 **Common** cards are the only exception — they can scale freely and fill the remaining space.


---

## 🧮 Stat Allocation Rules

Cards have **three core stats**: `Power`, `Charm`, and `Wit`.

- The **sum** of these three stats **must not exceed** the max for the rarity tier.
- Stats can be distributed however you want, as long as the total stays within the cap.
- Minimum stat per field: `0`  
- Maximum per stat: Not enforced, but try to keep cards balanced visually and mechanically.

---

## ✨ Rarity Visual Guide

The standard cards have the following :

- 🌱 Common – Gray
- 🔸 Uncommon – Green
- 🔷 Rare – Blue
- 🔮 Epic – Gold
- 🌈 Legendary – Purple

